@@ -25,7 +25,6 @@
 #include <rest/oauth-proxy.h>
 #include <json-glib/json-glib.h>
 
-#include "goalogging.h"
 #include "goaprovider.h"
 #include "goaprovider-priv.h"
 #include "goaoauth2provider.h"
@@ -224,10 +223,10 @@ get_identity_sync (GoaOAuth2Provider  *provider,
                                    rest_proxy_call_get_payload_length (call),
                                    &identity_error))
     {
-      goa_warning ("json_parser_load_from_data() failed: %s (%s, %d)",
-                   identity_error->message,
-                   g_quark_to_string (identity_error->domain),
-                   identity_error->code);
+      g_warning ("json_parser_load_from_data() failed: %s (%s, %d)",
+                 identity_error->message,
+                 g_quark_to_string (identity_error->domain),
+                 identity_error->code);
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
@@ -239,7 +238,7 @@ get_identity_sync (GoaOAuth2Provider  *provider,
   email = g_strdup (json_object_get_string_member (json_object, "email"));
   if (email == NULL)
     {
-      goa_warning ("Did not find email in JSON data");
+      g_warning ("Did not find email in JSON data");
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
