@@ -24,7 +24,6 @@
 #include <rest/oauth-proxy.h>
 #include <json-glib/json-glib.h>
 
-#include "goalogging.h"
 #include "goaprovider.h"
 #include "goaprovider-priv.h"
 #include "goaoauthprovider.h"
@@ -173,10 +172,10 @@ get_identity_sync (GoaOAuthProvider  *provider,
                                    rest_proxy_call_get_payload_length (call),
                                    &identity_error))
     {
-      goa_warning ("json_parser_load_from_data() failed: %s (%s, %d)",
-                   identity_error->message,
-                   g_quark_to_string (identity_error->domain),
-                   identity_error->code);
+      g_warning ("json_parser_load_from_data() failed: %s (%s, %d)",
+                 identity_error->message,
+                 g_quark_to_string (identity_error->domain),
+                 identity_error->code);
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
@@ -188,7 +187,7 @@ get_identity_sync (GoaOAuthProvider  *provider,
   id = g_strdup (json_object_get_string_member (json_object, "id_str"));
   if (id == NULL)
     {
-      goa_warning ("Did not find id_str in JSON data");
+      g_warning ("Did not find id_str in JSON data");
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
@@ -198,7 +197,7 @@ get_identity_sync (GoaOAuthProvider  *provider,
   presentation_identity = g_strdup (json_object_get_string_member (json_object, "screen_name"));
   if (presentation_identity == NULL)
     {
-      goa_warning ("Did not find screen_name in JSON data");
+      g_warning ("Did not find screen_name in JSON data");
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
